@@ -4,11 +4,16 @@
 # --------------------------------------------------------------------------------------------
 
 import os
+from collections import namedtuple
+
 from knack.log import get_logger
 
 logger = get_logger(__name__)
 
 
+AccessToken = namedtuple("AccessToken", ["token", "expires_on"])
+
+
 def aad_error_handler(error, **kwargs):
     """ Handle the error from AAD server returned by ADAL or MSAL. """
 
